{"": "", "Power off": "", "Not available": "", "System uptime": "", "Reboot": "", "Discharging at {{battery.rate}} W": "", "{{battery.voltage}} V": "", "Charging": "", "Hibernate": "", "Power": "", "Machine will become unreachable. Continue?": "", "Machine may become unreachable. Continue?": "", "System is suspending": "", "No batteries detected": "", "No adapters detected": "", "Power management": "", "System is hibernating": "", "Adapters": "", "Power state": "", "Suspend": "", "Shutdown and reboot the system": "", "Plugged in": "", "System is rebooting. We will try to reconnect with it.": "", "Batteries": "", "Warning": "", "Shutdown": "", "Cancel": ""}