{"": "", "Power off": "Spegni", "Not available": "Non disponibile", "System uptime": "Tempo di accensione del sistema", "Reboot": "Riavvia", "Discharging at {{battery.rate}} W": "Scaricamento a {{battery.rate}} W", "{{battery.voltage}} V": "{{battery.voltage}} V", "Charging": "In carica", "Hibernate": "Ibernazione", "Power": "Alimentazione", "Machine will become unreachable. Continue?": "Il sistema sar\u00e0 non raggiungibile. Continuare?", "Machine may become unreachable. Continue?": "Il sistema sar\u00e0 non raggiungibile. Continuare?", "System is suspending": "Il sistema \u00e8 in sospensione", "No batteries detected": "Batterie non rilevate", "No adapters detected": "Nessun adattatore rilevato", "Power management": "Gestione dell'alimentazione", "System is hibernating": "Sistema \u00e8 in ibernazione", "Adapters": "Adattatori", "Power state": "Stato di alimentazione", "Suspend": "Sospensione", "Shutdown and reboot the system": "Arresto e riavvio del sistema", "Plugged in": "Collegato", "System is rebooting. We will try to reconnect with it.": "Il sistema si sta riavviando. Riconnessione in corso.", "Batteries": "Batterie", "Warning": "Attenzione", "Shutdown": "Spegni", "Cancel": "Annulla"}